# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ColumnRuleInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _ancestor: Optional[ColumnRuleAncestorInputV1]
    _asset_creator: Optional[ColumnRuleAssetCreatorInputV1]
    _concat_columns: Optional[ColumnRuleConcatInputV1]
    _constant: Optional[ColumnRuleConstantInputV1]
    _context_condition: Optional[ColumnRuleContextConditionInputV1]
    _datasource: Optional[ColumnRuleDatasourceInputV1]
    _descendant: Optional[ColumnRuleDescendantInputV1]
    _descendant_search: Optional[ColumnRuleDescendantSearchInputV1]
    _event_asset_creator: Optional[ColumnRuleEventAssetCreatorInputV1]
    _event_property: Optional[ColumnRuleEventPropertyInputV1]
    _find_descendant: Optional[ColumnRuleFindDescendantInputV1]
    _find_property: Optional[ColumnRuleFindPropertyInputV1]
    _formula_creator: Optional[ColumnRuleFormulaCreatorInputV1]
    _get_item_property: Optional[ColumnRuleGetItemPropertyInputV1]
    _item_search: Optional[ColumnRuleItemSearchInputV1]
    _item_type: Optional[ColumnRuleItemTypeInputV1]
    _manager: Optional[ColumnRuleManagerInputV1]
    _path: Optional[ColumnRulePathInputV1]
    _path_search: Optional[ColumnRulePathSearchInputV1]
    _preserve_existing: Optional[ColumnRulePreserveExistingInputV1]
    _scalar_creator: Optional[ColumnRuleScalarCreatorInputV1]
    _search_ancestor: Optional[ColumnRuleSearchAncestorInputV1]
    _set_item_property: Optional[ColumnRuleSetItemPropertyInputV1]
    _text_extractor: Optional[ColumnRuleTextExtractorInputV1]
    _text_replacement: Optional[ColumnRuleTextReplacementInputV1]
    _tree_path_creator: Optional[ColumnRuleTreePathCreatorInputV1]


    def __init__(
        self,
        ancestor: Optional[ColumnRuleAncestorInputV1] = None,
        asset_creator: Optional[ColumnRuleAssetCreatorInputV1] = None,
        concat_columns: Optional[ColumnRuleConcatInputV1] = None,
        constant: Optional[ColumnRuleConstantInputV1] = None,
        context_condition: Optional[ColumnRuleContextConditionInputV1] = None,
        datasource: Optional[ColumnRuleDatasourceInputV1] = None,
        descendant: Optional[ColumnRuleDescendantInputV1] = None,
        descendant_search: Optional[ColumnRuleDescendantSearchInputV1] = None,
        event_asset_creator: Optional[ColumnRuleEventAssetCreatorInputV1] = None,
        event_property: Optional[ColumnRuleEventPropertyInputV1] = None,
        find_descendant: Optional[ColumnRuleFindDescendantInputV1] = None,
        find_property: Optional[ColumnRuleFindPropertyInputV1] = None,
        formula_creator: Optional[ColumnRuleFormulaCreatorInputV1] = None,
        get_item_property: Optional[ColumnRuleGetItemPropertyInputV1] = None,
        item_search: Optional[ColumnRuleItemSearchInputV1] = None,
        item_type: Optional[ColumnRuleItemTypeInputV1] = None,
        manager: Optional[ColumnRuleManagerInputV1] = None,
        path: Optional[ColumnRulePathInputV1] = None,
        path_search: Optional[ColumnRulePathSearchInputV1] = None,
        preserve_existing: Optional[ColumnRulePreserveExistingInputV1] = None,
        scalar_creator: Optional[ColumnRuleScalarCreatorInputV1] = None,
        search_ancestor: Optional[ColumnRuleSearchAncestorInputV1] = None,
        set_item_property: Optional[ColumnRuleSetItemPropertyInputV1] = None,
        text_extractor: Optional[ColumnRuleTextExtractorInputV1] = None,
        text_replacement: Optional[ColumnRuleTextReplacementInputV1] = None,
        tree_path_creator: Optional[ColumnRuleTreePathCreatorInputV1] = None,
    ) -> None: ...

    @property
    def ancestor(self) -> Optional[ColumnRuleAncestorInputV1]: ...

    @ancestor.setter
    def ancestor(self, ancestor: Optional[ColumnRuleAncestorInputV1]) -> None: ...

    @property
    def asset_creator(self) -> Optional[ColumnRuleAssetCreatorInputV1]: ...

    @asset_creator.setter
    def asset_creator(self, asset_creator: Optional[ColumnRuleAssetCreatorInputV1]) -> None: ...

    @property
    def concat_columns(self) -> Optional[ColumnRuleConcatInputV1]: ...

    @concat_columns.setter
    def concat_columns(self, concat_columns: Optional[ColumnRuleConcatInputV1]) -> None: ...

    @property
    def constant(self) -> Optional[ColumnRuleConstantInputV1]: ...

    @constant.setter
    def constant(self, constant: Optional[ColumnRuleConstantInputV1]) -> None: ...

    @property
    def context_condition(self) -> Optional[ColumnRuleContextConditionInputV1]: ...

    @context_condition.setter
    def context_condition(self, context_condition: Optional[ColumnRuleContextConditionInputV1]) -> None: ...

    @property
    def datasource(self) -> Optional[ColumnRuleDatasourceInputV1]: ...

    @datasource.setter
    def datasource(self, datasource: Optional[ColumnRuleDatasourceInputV1]) -> None: ...

    @property
    def descendant(self) -> Optional[ColumnRuleDescendantInputV1]: ...

    @descendant.setter
    def descendant(self, descendant: Optional[ColumnRuleDescendantInputV1]) -> None: ...

    @property
    def descendant_search(self) -> Optional[ColumnRuleDescendantSearchInputV1]: ...

    @descendant_search.setter
    def descendant_search(self, descendant_search: Optional[ColumnRuleDescendantSearchInputV1]) -> None: ...

    @property
    def event_asset_creator(self) -> Optional[ColumnRuleEventAssetCreatorInputV1]: ...

    @event_asset_creator.setter
    def event_asset_creator(self, event_asset_creator: Optional[ColumnRuleEventAssetCreatorInputV1]) -> None: ...

    @property
    def event_property(self) -> Optional[ColumnRuleEventPropertyInputV1]: ...

    @event_property.setter
    def event_property(self, event_property: Optional[ColumnRuleEventPropertyInputV1]) -> None: ...

    @property
    def find_descendant(self) -> Optional[ColumnRuleFindDescendantInputV1]: ...

    @find_descendant.setter
    def find_descendant(self, find_descendant: Optional[ColumnRuleFindDescendantInputV1]) -> None: ...

    @property
    def find_property(self) -> Optional[ColumnRuleFindPropertyInputV1]: ...

    @find_property.setter
    def find_property(self, find_property: Optional[ColumnRuleFindPropertyInputV1]) -> None: ...

    @property
    def formula_creator(self) -> Optional[ColumnRuleFormulaCreatorInputV1]: ...

    @formula_creator.setter
    def formula_creator(self, formula_creator: Optional[ColumnRuleFormulaCreatorInputV1]) -> None: ...

    @property
    def get_item_property(self) -> Optional[ColumnRuleGetItemPropertyInputV1]: ...

    @get_item_property.setter
    def get_item_property(self, get_item_property: Optional[ColumnRuleGetItemPropertyInputV1]) -> None: ...

    @property
    def item_search(self) -> Optional[ColumnRuleItemSearchInputV1]: ...

    @item_search.setter
    def item_search(self, item_search: Optional[ColumnRuleItemSearchInputV1]) -> None: ...

    @property
    def item_type(self) -> Optional[ColumnRuleItemTypeInputV1]: ...

    @item_type.setter
    def item_type(self, item_type: Optional[ColumnRuleItemTypeInputV1]) -> None: ...

    @property
    def manager(self) -> Optional[ColumnRuleManagerInputV1]: ...

    @manager.setter
    def manager(self, manager: Optional[ColumnRuleManagerInputV1]) -> None: ...

    @property
    def path(self) -> Optional[ColumnRulePathInputV1]: ...

    @path.setter
    def path(self, path: Optional[ColumnRulePathInputV1]) -> None: ...

    @property
    def path_search(self) -> Optional[ColumnRulePathSearchInputV1]: ...

    @path_search.setter
    def path_search(self, path_search: Optional[ColumnRulePathSearchInputV1]) -> None: ...

    @property
    def preserve_existing(self) -> Optional[ColumnRulePreserveExistingInputV1]: ...

    @preserve_existing.setter
    def preserve_existing(self, preserve_existing: Optional[ColumnRulePreserveExistingInputV1]) -> None: ...

    @property
    def scalar_creator(self) -> Optional[ColumnRuleScalarCreatorInputV1]: ...

    @scalar_creator.setter
    def scalar_creator(self, scalar_creator: Optional[ColumnRuleScalarCreatorInputV1]) -> None: ...

    @property
    def search_ancestor(self) -> Optional[ColumnRuleSearchAncestorInputV1]: ...

    @search_ancestor.setter
    def search_ancestor(self, search_ancestor: Optional[ColumnRuleSearchAncestorInputV1]) -> None: ...

    @property
    def set_item_property(self) -> Optional[ColumnRuleSetItemPropertyInputV1]: ...

    @set_item_property.setter
    def set_item_property(self, set_item_property: Optional[ColumnRuleSetItemPropertyInputV1]) -> None: ...

    @property
    def text_extractor(self) -> Optional[ColumnRuleTextExtractorInputV1]: ...

    @text_extractor.setter
    def text_extractor(self, text_extractor: Optional[ColumnRuleTextExtractorInputV1]) -> None: ...

    @property
    def text_replacement(self) -> Optional[ColumnRuleTextReplacementInputV1]: ...

    @text_replacement.setter
    def text_replacement(self, text_replacement: Optional[ColumnRuleTextReplacementInputV1]) -> None: ...

    @property
    def tree_path_creator(self) -> Optional[ColumnRuleTreePathCreatorInputV1]: ...

    @tree_path_creator.setter
    def tree_path_creator(self, tree_path_creator: Optional[ColumnRuleTreePathCreatorInputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class StoredTablesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_stored_table_from_csv(self, **kwargs):
        """
        Create a new stored table from CSV. The column order will be equal to the order in the CSV.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_stored_table_from_csv(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param StoredTableCSVInputV1 body: (required)
        :return: StoredTableOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StoredTableOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_stored_table_from_csv_with_http_info(**kwargs)
        else:
            (data) = self.create_stored_table_from_csv_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def create_stored_table_from_csv_with_http_info(self, **kwargs):
        """
        Create a new stored table from CSV. The column order will be equal to the order in the CSV.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_stored_table_from_csv_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param StoredTableCSVInputV1 body: (required)
        :return: StoredTableOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StoredTableOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_stored_table_from_csv" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_stored_table_from_csv`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/stored-tables/csv/create', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StoredTableOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def delete_column_from_stored_table(self, **kwargs):
        """
        Delete a column from a stored table. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_column_from_stored_table(id=id_value, column_id=column_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the stored table (required)
        :param str column_id: The column ID to be deleted (required)
        :return: StoredTableOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StoredTableOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_column_from_stored_table_with_http_info(**kwargs)
        else:
            (data) = self.delete_column_from_stored_table_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def delete_column_from_stored_table_with_http_info(self, **kwargs):
        """
        Delete a column from a stored table. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_column_from_stored_table_with_http_info(id=id_value, column_id=column_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The Seeq ID for the stored table (required)
        :param str column_id: The column ID to be deleted (required)
        :return: StoredTableOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StoredTableOutputV1
        """

        all_params = ['id', 'column_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_column_from_stored_table" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_column_from_stored_table`")
        # verify the required parameter 'column_id' is set
        if ('column_id' not in params) or (params['column_id'] is None):
            raise ValueError("Missing the required parameter `column_id` when calling `delete_column_from_stored_table`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']
        if 'column_id' in params:
            path_params['columnId'] = params['column_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/stored-tables/{id}/columns/{columnId}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StoredTableOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def delete_stored_table_rows(self, **kwargs):
        """
        Delete rows from a stored table
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_stored_table_rows(body=body_value, table_id=table_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param StoredTableDeleteRowsInputV1 body: (required)
        :param str table_id: The id of the table to delete rows from (required)
        :return: DeleteRowsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeleteRowsOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_stored_table_rows_with_http_info(**kwargs)
        else:
            (data) = self.delete_stored_table_rows_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def delete_stored_table_rows_with_http_info(self, **kwargs):
        """
        Delete rows from a stored table
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_stored_table_rows_with_http_info(body=body_value, table_id=table_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param StoredTableDeleteRowsInputV1 body: (required)
        :param str table_id: The id of the table to delete rows from (required)
        :return: DeleteRowsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeleteRowsOutputV1
        """

        all_params = ['body', 'table_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_stored_table_rows" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `delete_stored_table_rows`")
        # verify the required parameter 'table_id' is set
        if ('table_id' not in params) or (params['table_id'] is None):
            raise ValueError("Missing the required parameter `table_id` when calling `delete_stored_table_rows`")


        collection_formats = {}

        path_params = {}
        if 'table_id' in params:
            path_params['tableId'] = params['table_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/stored-tables/{tableId}/deleteRows', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DeleteRowsOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_stored_table(self, **kwargs):
        """
        Get a stored table. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_stored_table(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the stored table (required)
        :return: StoredTableOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StoredTableOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_stored_table_with_http_info(**kwargs)
        else:
            (data) = self.get_stored_table_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def get_stored_table_with_http_info(self, **kwargs):
        """
        Get a stored table. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_stored_table_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The ID of the stored table (required)
        :return: StoredTableOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StoredTableOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_stored_table" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_stored_table`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/stored-tables/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StoredTableOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def import_stored_table_csv(self, **kwargs):
        """
        Import a CSV file that can be used to create a stored table
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.import_stored_table_csv(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str file:
        :return: ImportTableCSVOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ImportTableCSVOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.import_stored_table_csv_with_http_info(**kwargs)
        else:
            (data) = self.import_stored_table_csv_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def import_stored_table_csv_with_http_info(self, **kwargs):
        """
        Import a CSV file that can be used to create a stored table
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.import_stored_table_csv_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str file:
        :return: ImportTableCSVOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ImportTableCSVOutputV1
        """

        all_params = ['file']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_stored_table_csv" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/stored-tables/csv', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ImportTableCSVOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def modify_column_in_stored_table(self, **kwargs):
        """
        Modify a column in a stored table. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.modify_column_in_stored_table(body=body_value, id=id_value, column_id=column_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param StoredTableColumnInputV1 body: (required)
        :param str id: The Seeq ID for the stored table (required)
        :param str column_id: The column ID to be modified. Possible modifications are: changing the column's index, renaming the column, changing the column's type, and updating the column's unit of measure. Once a column has become a non-String type, it's type can not be changed.For type conversions:- String to TIMESTAMPTZ: If the string value is in ISO8601 format, it gets directly cast to a timestamp with the same information. If not, then it gets cast to the epoch timestamp.- String to Numeric: The string values will get directly converted into their numeric equivalent. So, '1' becomes 1, '1.5' becomes 1.5, 1e10 becomes 10000000000. So integers, decimals, and scientific notation is handled. If a string cannot become converted, it will be cast as null. Units of measure are parsed out of numeric values and stored separately if multiple exist. If only one unit of measure exists, it is set as the column uom.- String to Boolean: If 'false', 'f', or '0', convert to false. If 'true', 't', or '1', convert to true. The string to boolean conversion is case-insensitive. (required)
        :return: StoredTableOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StoredTableOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.modify_column_in_stored_table_with_http_info(**kwargs)
        else:
            (data) = self.modify_column_in_stored_table_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def modify_column_in_stored_table_with_http_info(self, **kwargs):
        """
        Modify a column in a stored table. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.modify_column_in_stored_table_with_http_info(body=body_value, id=id_value, column_id=column_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param StoredTableColumnInputV1 body: (required)
        :param str id: The Seeq ID for the stored table (required)
        :param str column_id: The column ID to be modified. Possible modifications are: changing the column's index, renaming the column, changing the column's type, and updating the column's unit of measure. Once a column has become a non-String type, it's type can not be changed.For type conversions:- String to TIMESTAMPTZ: If the string value is in ISO8601 format, it gets directly cast to a timestamp with the same information. If not, then it gets cast to the epoch timestamp.- String to Numeric: The string values will get directly converted into their numeric equivalent. So, '1' becomes 1, '1.5' becomes 1.5, 1e10 becomes 10000000000. So integers, decimals, and scientific notation is handled. If a string cannot become converted, it will be cast as null. Units of measure are parsed out of numeric values and stored separately if multiple exist. If only one unit of measure exists, it is set as the column uom.- String to Boolean: If 'false', 'f', or '0', convert to false. If 'true', 't', or '1', convert to true. The string to boolean conversion is case-insensitive. (required)
        :return: StoredTableOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StoredTableOutputV1
        """

        all_params = ['body', 'id', 'column_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method modify_column_in_stored_table" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `modify_column_in_stored_table`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `modify_column_in_stored_table`")
        # verify the required parameter 'column_id' is set
        if ('column_id' not in params) or (params['column_id'] is None):
            raise ValueError("Missing the required parameter `column_id` when calling `modify_column_in_stored_table`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']
        if 'column_id' in params:
            path_params['columnId'] = params['column_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/stored-tables/{id}/columns/{columnId}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StoredTableOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_column_data(self, **kwargs):
        """
        Update data in a column of a stored table. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_column_data(body=body_value, id=id_value, column_id=column_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ColumnDataUpdateInputListV1 body: The data updates to apply to the column (required)
        :param str id: The Seeq ID for the stored table (required)
        :param str column_id: The column ID that the data updates are being applied to (required)
        :return: UpdatedRowsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UpdatedRowsOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_column_data_with_http_info(**kwargs)
        else:
            (data) = self.update_column_data_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_column_data_with_http_info(self, **kwargs):
        """
        Update data in a column of a stored table. This endpoint is experimental and may change in future releases.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_column_data_with_http_info(body=body_value, id=id_value, column_id=column_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ColumnDataUpdateInputListV1 body: The data updates to apply to the column (required)
        :param str id: The Seeq ID for the stored table (required)
        :param str column_id: The column ID that the data updates are being applied to (required)
        :return: UpdatedRowsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UpdatedRowsOutputV1
        """

        all_params = ['body', 'id', 'column_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_column_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_column_data`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_column_data`")
        # verify the required parameter 'column_id' is set
        if ('column_id' not in params) or (params['column_id'] is None):
            raise ValueError("Missing the required parameter `column_id` when calling `update_column_data`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']
        if 'column_id' in params:
            path_params['columnId'] = params['column_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/stored-tables/{id}/columns/{columnId}/updateData', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'UpdatedRowsOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_stored_table_from_csv(self, **kwargs):
        """
        Update an existing stored table from a CSV. The column order will be equal to the order in the CSV. All existing data in the stored table will be preseved and new rows/columns from the new CSV will be added to the existing data.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_stored_table_from_csv(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param StoredTableCSVInputV1 body: (required)
        :param str id: The Seeq ID for the stored table (required)
        :return: StoredTableOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StoredTableOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_stored_table_from_csv_with_http_info(**kwargs)
        else:
            (data) = self.update_stored_table_from_csv_with_http_info(**kwargs)
            return data

    @deprecated(reason="This API is experimental and may change or be removed in future releases without prior notice.")
    def update_stored_table_from_csv_with_http_info(self, **kwargs):
        """
        Update an existing stored table from a CSV. The column order will be equal to the order in the CSV. All existing data in the stored table will be preseved and new rows/columns from the new CSV will be added to the existing data.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_stored_table_from_csv_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param StoredTableCSVInputV1 body: (required)
        :param str id: The Seeq ID for the stored table (required)
        :return: StoredTableOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StoredTableOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_stored_table_from_csv" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_stored_table_from_csv`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_stored_table_from_csv`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/stored-tables/{id}/csv/update', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StoredTableOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class AccessKeysApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def create_key(
        self,
        **kwargs: Any,
    ) -> AccessKeyOutputV1: ...

    def create_key_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_key(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_key_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_keys(
        self,
        **kwargs: Any,
    ) -> AccessKeyOutputListV1: ...

    def get_keys_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class JobsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_content_job(self, **kwargs):
        """
        Create a job to capture a content screenshot at a regular interval
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_content_job(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str body: ID of the content (required)
        :return: JobOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: JobOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_content_job_with_http_info(**kwargs)
        else:
            (data) = self.create_content_job_with_http_info(**kwargs)
            return data

    def create_content_job_with_http_info(self, **kwargs):
        """
        Create a job to capture a content screenshot at a regular interval
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_content_job_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str body: ID of the content (required)
        :return: JobOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: JobOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_content_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_content_job`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/jobs/content', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'JobOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_date_range_job(self, **kwargs):
        """
        Create a job to update a date range and its content at a regular interval
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_date_range_job(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str body: ID for the Date Range (required)
        :return: JobOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: JobOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_date_range_job_with_http_info(**kwargs)
        else:
            (data) = self.create_date_range_job_with_http_info(**kwargs)
            return data

    def create_date_range_job_with_http_info(self, **kwargs):
        """
        Create a job to update a date range and its content at a regular interval
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_date_range_job_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str body: ID for the Date Range (required)
        :return: JobOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: JobOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_date_range_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_date_range_job`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/jobs/dateRange', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'JobOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_job(self, **kwargs):
        """
        Delete a scheduled job and cancel any currently running instance
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_job(group=group_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group: Group to which the job belongs (required)
        :param str id: ID of the job to delete (required)
        :param str scheduler_type: Which scheduler to query for the job. The options are User (default), System, and AsyncMigration.
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_job_with_http_info(**kwargs)
        else:
            (data) = self.delete_job_with_http_info(**kwargs)
            return data

    def delete_job_with_http_info(self, **kwargs):
        """
        Delete a scheduled job and cancel any currently running instance
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_job_with_http_info(group=group_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group: Group to which the job belongs (required)
        :param str id: ID of the job to delete (required)
        :param str scheduler_type: Which scheduler to query for the job. The options are User (default), System, and AsyncMigration.
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['group', 'id', 'scheduler_type']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group' is set
        if ('group' not in params) or (params['group'] is None):
            raise ValueError("Missing the required parameter `group` when calling `delete_job`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_job`")


        collection_formats = {}

        path_params = {}
        if 'group' in params:
            path_params['group'] = params['group']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []
        if 'scheduler_type' in params:
            query_params.append(('schedulerType', params['scheduler_type']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/jobs/{group}/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_job(self, **kwargs):
        """
        Get details of a specified job
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_job(group=group_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group: Group to which the job belongs (required)
        :param str id: ID of the job to retrieve (required)
        :param str scheduler_type: Which scheduler to query for the job. The options are User (default), System, and AsyncMigration.
        :return: JobOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: JobOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_job_with_http_info(**kwargs)
        else:
            (data) = self.get_job_with_http_info(**kwargs)
            return data

    def get_job_with_http_info(self, **kwargs):
        """
        Get details of a specified job
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_job_with_http_info(group=group_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group: Group to which the job belongs (required)
        :param str id: ID of the job to retrieve (required)
        :param str scheduler_type: Which scheduler to query for the job. The options are User (default), System, and AsyncMigration.
        :return: JobOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: JobOutputV1
        """

        all_params = ['group', 'id', 'scheduler_type']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group' is set
        if ('group' not in params) or (params['group'] is None):
            raise ValueError("Missing the required parameter `group` when calling `get_job`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_job`")


        collection_formats = {}

        path_params = {}
        if 'group' in params:
            path_params['group'] = params['group']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []
        if 'scheduler_type' in params:
            query_params.append(('schedulerType', params['scheduler_type']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/jobs/{group}/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'JobOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_jobs(self, **kwargs):
        """
        List of scheduled jobs
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_jobs(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first job that will be returned in this page of results
        :param int limit: The pagination limit, the total number of jobs that will be returned in this page of results
        :param str scheduler_type: Which scheduler to query for jobs. The options are User (default), System, and AsyncMigration.
        :return: GetJobsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetJobsOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_jobs_with_http_info(**kwargs)
        else:
            (data) = self.get_jobs_with_http_info(**kwargs)
            return data

    def get_jobs_with_http_info(self, **kwargs):
        """
        List of scheduled jobs
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_jobs_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first job that will be returned in this page of results
        :param int limit: The pagination limit, the total number of jobs that will be returned in this page of results
        :param str scheduler_type: Which scheduler to query for jobs. The options are User (default), System, and AsyncMigration.
        :return: GetJobsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetJobsOutputV1
        """

        all_params = ['offset', 'limit', 'scheduler_type']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_jobs" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'scheduler_type' in params:
            query_params.append(('schedulerType', params['scheduler_type']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/jobs', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'GetJobsOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_screenshot_from_content(self, **kwargs):
        """
        A simplified endpoint for fetching a screenshot of Seeq content at a regular interval.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_screenshot_from_content(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The content id to capture (required)
        :return: ScreenshotOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScreenshotOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_screenshot_from_content_with_http_info(**kwargs)
        else:
            (data) = self.get_screenshot_from_content_with_http_info(**kwargs)
            return data

    def get_screenshot_from_content_with_http_info(self, **kwargs):
        """
        A simplified endpoint for fetching a screenshot of Seeq content at a regular interval.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_screenshot_from_content_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The content id to capture (required)
        :return: ScreenshotOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScreenshotOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_screenshot_from_content" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_screenshot_from_content`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/jobs/content/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ScreenshotOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def validate_cron(self, **kwargs):
        """
        Validate a list of Quartz cron expressions
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.validate_cron(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ValidateCronListInputV1 body: The list of cron schedules to evaluate (required)
        :return: ValidateCronListOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ValidateCronListOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.validate_cron_with_http_info(**kwargs)
        else:
            (data) = self.validate_cron_with_http_info(**kwargs)
            return data

    def validate_cron_with_http_info(self, **kwargs):
        """
        Validate a list of Quartz cron expressions
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.validate_cron_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ValidateCronListInputV1 body: The list of cron schedules to evaluate (required)
        :return: ValidateCronListOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ValidateCronListOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method validate_cron" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `validate_cron`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/jobs/validateCron', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ValidateCronListOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConditionTableInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _capsule_properties: Optional[List[str]]
    _condition_properties: Optional[List[str]]
    _condition_source: ConditionSourceV1
    _end: Value
    _filter: Optional[Filter]
    _include_asset_column: Optional[bool]
    _limit: int
    _start: Value


    def __init__(
        self,
        capsule_properties: Optional[List[str]] = None,
        condition_properties: Optional[List[str]] = None,
        condition_source: Optional[ConditionSourceV1] = None,
        end: Optional[Value] = None,
        filter: Optional[Filter] = None,
        include_asset_column: Optional[bool] = True,
        limit: Optional[int] = 40,
        start: Optional[Value] = None,
    ) -> None: ...

    @property
    def capsule_properties(self) -> Optional[List[str]]: ...

    @capsule_properties.setter
    def capsule_properties(self, capsule_properties: Optional[List[str]]) -> None: ...

    @property
    def condition_properties(self) -> Optional[List[str]]: ...

    @condition_properties.setter
    def condition_properties(self, condition_properties: Optional[List[str]]) -> None: ...

    @property
    def condition_source(self) -> ConditionSourceV1: ...

    @condition_source.setter
    def condition_source(self, condition_source: ConditionSourceV1) -> None: ...

    @property
    def end(self) -> Value: ...

    @end.setter
    def end(self, end: Value) -> None: ...

    @property
    def filter(self) -> Optional[Filter]: ...

    @filter.setter
    def filter(self, filter: Optional[Filter]) -> None: ...

    @property
    def include_asset_column(self) -> Optional[bool]: ...

    @include_asset_column.setter
    def include_asset_column(self, include_asset_column: Optional[bool]) -> None: ...

    @property
    def limit(self) -> int: ...

    @limit.setter
    def limit(self, limit: int) -> None: ...

    @property
    def start(self) -> Value: ...

    @start.setter
    def start(self, start: Value) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FeatureRuleV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _boolean_constant: Optional[ModelBooleanConstantRuleV1]
    _formula_creator: Optional[ModelFormulaCreatorRuleV1]
    _id: Optional[str]
    _inputs: List[ModelRuleInputV1Object]
    _numeric_scalar_creator: Optional[ModelScalarCreatorRuleV1]
    _string_scalar_creator: Optional[ModelScalarCreatorRuleV1]


    def __init__(
        self,
        boolean_constant: Optional[ModelBooleanConstantRuleV1] = None,
        formula_creator: Optional[ModelFormulaCreatorRuleV1] = None,
        id: Optional[str] = None,
        inputs: Optional[List[ModelRuleInputV1Object]] = None,
        numeric_scalar_creator: Optional[ModelScalarCreatorRuleV1] = None,
        string_scalar_creator: Optional[ModelScalarCreatorRuleV1] = None,
    ) -> None: ...

    @property
    def boolean_constant(self) -> Optional[ModelBooleanConstantRuleV1]: ...

    @boolean_constant.setter
    def boolean_constant(self, boolean_constant: Optional[ModelBooleanConstantRuleV1]) -> None: ...

    @property
    def formula_creator(self) -> Optional[ModelFormulaCreatorRuleV1]: ...

    @formula_creator.setter
    def formula_creator(self, formula_creator: Optional[ModelFormulaCreatorRuleV1]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def inputs(self) -> List[ModelRuleInputV1Object]: ...

    @inputs.setter
    def inputs(self, inputs: List[ModelRuleInputV1Object]) -> None: ...

    @property
    def numeric_scalar_creator(self) -> Optional[ModelScalarCreatorRuleV1]: ...

    @numeric_scalar_creator.setter
    def numeric_scalar_creator(self, numeric_scalar_creator: Optional[ModelScalarCreatorRuleV1]) -> None: ...

    @property
    def string_scalar_creator(self) -> Optional[ModelScalarCreatorRuleV1]: ...

    @string_scalar_creator.setter
    def string_scalar_creator(self, string_scalar_creator: Optional[ModelScalarCreatorRuleV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConditionMonitorInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capsule_event_types': 'list[str]',
        'condition_ids': 'list[str]',
        'cron_schedule': 'list[str]',
        'description': 'str',
        'enabled': 'bool',
        'first_run_look_back': 'int',
        'item_finder_id': 'str',
        'name': 'str',
        'query_range_look_ahead': 'int',
        'scoped_to': 'str',
        'suppressed_conditions': 'list[SuppressedConditionInputV1]',
        'timezone': 'str',
        'webhook_url': 'str'
    }

    attribute_map = {
        'capsule_event_types': 'capsuleEventTypes',
        'condition_ids': 'conditionIds',
        'cron_schedule': 'cronSchedule',
        'description': 'description',
        'enabled': 'enabled',
        'first_run_look_back': 'firstRunLookBack',
        'item_finder_id': 'itemFinderId',
        'name': 'name',
        'query_range_look_ahead': 'queryRangeLookAhead',
        'scoped_to': 'scopedTo',
        'suppressed_conditions': 'suppressedConditions',
        'timezone': 'timezone',
        'webhook_url': 'webhookUrl'
    }

    def __init__(self, capsule_event_types=None, condition_ids=None, cron_schedule=None, description=None, enabled=True, first_run_look_back=None, item_finder_id=None, name=None, query_range_look_ahead=None, scoped_to=None, suppressed_conditions=None, timezone=None, webhook_url=None):
        """
        ConditionMonitorInputV1 - a model defined in Swagger
        """

        self._capsule_event_types = None
        self._condition_ids = None
        self._cron_schedule = None
        self._description = None
        self._enabled = None
        self._first_run_look_back = None
        self._item_finder_id = None
        self._name = None
        self._query_range_look_ahead = None
        self._scoped_to = None
        self._suppressed_conditions = None
        self._timezone = None
        self._webhook_url = None

        if capsule_event_types is not None:
          self.capsule_event_types = capsule_event_types
        if condition_ids is not None:
          self.condition_ids = condition_ids
        if cron_schedule is not None:
          self.cron_schedule = cron_schedule
        if description is not None:
          self.description = description
        if enabled is not None:
          self.enabled = enabled
        if first_run_look_back is not None:
          self.first_run_look_back = first_run_look_back
        if item_finder_id is not None:
          self.item_finder_id = item_finder_id
        if name is not None:
          self.name = name
        if query_range_look_ahead is not None:
          self.query_range_look_ahead = query_range_look_ahead
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if suppressed_conditions is not None:
          self.suppressed_conditions = suppressed_conditions
        if timezone is not None:
          self.timezone = timezone
        if webhook_url is not None:
          self.webhook_url = webhook_url

    @property
    def capsule_event_types(self):
        """
        Gets the capsule_event_types of this ConditionMonitorInputV1.
        The list of capsule event types to detect. The list can contain one or more of the following values: NEW: Detects new capsules that were not present in the previous run. BECAME_CERTAIN: Detects capsules that were previously uncertain and became certain. STILL_UNCERTAIN: Detects capsules that were previously uncertain and are still uncertain. EXTINCT: Detects capsules that were previously uncertain and became extinct. Defaults to [NEW, BECAME_CERTAIN, EXTINCT]

        :return: The capsule_event_types of this ConditionMonitorInputV1.
        :rtype: list[str]
        """
        return self._capsule_event_types

    @capsule_event_types.setter
    def capsule_event_types(self, capsule_event_types):
        """
        Sets the capsule_event_types of this ConditionMonitorInputV1.
        The list of capsule event types to detect. The list can contain one or more of the following values: NEW: Detects new capsules that were not present in the previous run. BECAME_CERTAIN: Detects capsules that were previously uncertain and became certain. STILL_UNCERTAIN: Detects capsules that were previously uncertain and are still uncertain. EXTINCT: Detects capsules that were previously uncertain and became extinct. Defaults to [NEW, BECAME_CERTAIN, EXTINCT]

        :param capsule_event_types: The capsule_event_types of this ConditionMonitorInputV1.
        :type: list[str]
        """

        self._capsule_event_types = capsule_event_types

    @property
    def condition_ids(self):
        """
        Gets the condition_ids of this ConditionMonitorInputV1.
        The IDs of conditions to monitor

        :return: The condition_ids of this ConditionMonitorInputV1.
        :rtype: list[str]
        """
        return self._condition_ids

    @condition_ids.setter
    def condition_ids(self, condition_ids):
        """
        Sets the condition_ids of this ConditionMonitorInputV1.
        The IDs of conditions to monitor

        :param condition_ids: The condition_ids of this ConditionMonitorInputV1.
        :type: list[str]
        """

        self._condition_ids = condition_ids

    @property
    def cron_schedule(self):
        """
        Gets the cron_schedule of this ConditionMonitorInputV1.
        The condition monitor's check interval(s) as a list of cron expressions. If the list is empty, the system wide default check schedule is used. For more information about cron expressions, see  http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html

        :return: The cron_schedule of this ConditionMonitorInputV1.
        :rtype: list[str]
        """
        return self._cron_schedule

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule):
        """
        Sets the cron_schedule of this ConditionMonitorInputV1.
        The condition monitor's check interval(s) as a list of cron expressions. If the list is empty, the system wide default check schedule is used. For more information about cron expressions, see  http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html

        :param cron_schedule: The cron_schedule of this ConditionMonitorInputV1.
        :type: list[str]
        """

        self._cron_schedule = cron_schedule

    @property
    def description(self):
        """
        Gets the description of this ConditionMonitorInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :return: The description of this ConditionMonitorInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ConditionMonitorInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :param description: The description of this ConditionMonitorInputV1.
        :type: str
        """

        self._description = description

    @property
    def enabled(self):
        """
        Gets the enabled of this ConditionMonitorInputV1.
        Whether the condition monitor is enabled

        :return: The enabled of this ConditionMonitorInputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ConditionMonitorInputV1.
        Whether the condition monitor is enabled

        :param enabled: The enabled of this ConditionMonitorInputV1.
        :type: bool
        """

        self._enabled = enabled

    @property
    def first_run_look_back(self):
        """
        Gets the first_run_look_back of this ConditionMonitorInputV1.
        On first run, how far to look back for capsules, in seconds

        :return: The first_run_look_back of this ConditionMonitorInputV1.
        :rtype: int
        """
        return self._first_run_look_back

    @first_run_look_back.setter
    def first_run_look_back(self, first_run_look_back):
        """
        Sets the first_run_look_back of this ConditionMonitorInputV1.
        On first run, how far to look back for capsules, in seconds

        :param first_run_look_back: The first_run_look_back of this ConditionMonitorInputV1.
        :type: int
        """

        self._first_run_look_back = first_run_look_back

    @property
    def item_finder_id(self):
        """
        Gets the item_finder_id of this ConditionMonitorInputV1.
        The ID of an Item Finder to use to populate the list of conditions. If this is provided it will overwrite the list of conditionIds

        :return: The item_finder_id of this ConditionMonitorInputV1.
        :rtype: str
        """
        return self._item_finder_id

    @item_finder_id.setter
    def item_finder_id(self, item_finder_id):
        """
        Sets the item_finder_id of this ConditionMonitorInputV1.
        The ID of an Item Finder to use to populate the list of conditions. If this is provided it will overwrite the list of conditionIds

        :param item_finder_id: The item_finder_id of this ConditionMonitorInputV1.
        :type: str
        """

        self._item_finder_id = item_finder_id

    @property
    def name(self):
        """
        Gets the name of this ConditionMonitorInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :return: The name of this ConditionMonitorInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConditionMonitorInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :param name: The name of this ConditionMonitorInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def query_range_look_ahead(self):
        """
        Gets the query_range_look_ahead of this ConditionMonitorInputV1.
        Query range look ahead in seconds

        :return: The query_range_look_ahead of this ConditionMonitorInputV1.
        :rtype: int
        """
        return self._query_range_look_ahead

    @query_range_look_ahead.setter
    def query_range_look_ahead(self, query_range_look_ahead):
        """
        Sets the query_range_look_ahead of this ConditionMonitorInputV1.
        Query range look ahead in seconds

        :param query_range_look_ahead: The query_range_look_ahead of this ConditionMonitorInputV1.
        :type: int
        """

        self._query_range_look_ahead = query_range_look_ahead

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ConditionMonitorInputV1.
        The ID of the workbook to which this item will be scoped. If not provided, the condition monitor will have global scope.

        :return: The scoped_to of this ConditionMonitorInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ConditionMonitorInputV1.
        The ID of the workbook to which this item will be scoped. If not provided, the condition monitor will have global scope.

        :param scoped_to: The scoped_to of this ConditionMonitorInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def suppressed_conditions(self):
        """
        Gets the suppressed_conditions of this ConditionMonitorInputV1.
        The conditions and associated logic to suppress in this monitor

        :return: The suppressed_conditions of this ConditionMonitorInputV1.
        :rtype: list[SuppressedConditionInputV1]
        """
        return self._suppressed_conditions

    @suppressed_conditions.setter
    def suppressed_conditions(self, suppressed_conditions):
        """
        Sets the suppressed_conditions of this ConditionMonitorInputV1.
        The conditions and associated logic to suppress in this monitor

        :param suppressed_conditions: The suppressed_conditions of this ConditionMonitorInputV1.
        :type: list[SuppressedConditionInputV1]
        """

        self._suppressed_conditions = suppressed_conditions

    @property
    def timezone(self):
        """
        Gets the timezone of this ConditionMonitorInputV1.
        The IANA timezone in which the scheduled times will be run, defaults to UTC

        :return: The timezone of this ConditionMonitorInputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this ConditionMonitorInputV1.
        The IANA timezone in which the scheduled times will be run, defaults to UTC

        :param timezone: The timezone of this ConditionMonitorInputV1.
        :type: str
        """

        self._timezone = timezone

    @property
    def webhook_url(self):
        """
        Gets the webhook_url of this ConditionMonitorInputV1.
        A relative HTTP endpoint that is invoked whenever new capsules are found or existing capsules end in any of the conditions.

        :return: The webhook_url of this ConditionMonitorInputV1.
        :rtype: str
        """
        return self._webhook_url

    @webhook_url.setter
    def webhook_url(self, webhook_url):
        """
        Sets the webhook_url of this ConditionMonitorInputV1.
        A relative HTTP endpoint that is invoked whenever new capsules are found or existing capsules end in any of the conditions.

        :param webhook_url: The webhook_url of this ConditionMonitorInputV1.
        :type: str
        """

        self._webhook_url = webhook_url

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConditionMonitorInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ColumnRuleFindDescendantInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column_index: int
    _item_types: Optional[List[str]]
    _property_match_operators: List[str]
    _property_names: List[str]
    _property_value_types: Optional[List[str]]
    _property_value_uoms: Optional[List[str]]
    _property_values: List[str]


    def __init__(
        self,
        column_index: Optional[int] = None,
        item_types: Optional[List[str]] = None,
        property_match_operators: Optional[List[str]] = None,
        property_names: Optional[List[str]] = None,
        property_value_types: Optional[List[str]] = None,
        property_value_uoms: Optional[List[str]] = None,
        property_values: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def column_index(self) -> int: ...

    @column_index.setter
    def column_index(self, column_index: int) -> None: ...

    @property
    def item_types(self) -> Optional[List[str]]: ...

    @item_types.setter
    def item_types(self, item_types: Optional[List[str]]) -> None: ...

    @property
    def property_match_operators(self) -> List[str]: ...

    @property_match_operators.setter
    def property_match_operators(self, property_match_operators: List[str]) -> None: ...

    @property
    def property_names(self) -> List[str]: ...

    @property_names.setter
    def property_names(self, property_names: List[str]) -> None: ...

    @property
    def property_value_types(self) -> Optional[List[str]]: ...

    @property_value_types.setter
    def property_value_types(self, property_value_types: Optional[List[str]]) -> None: ...

    @property
    def property_value_uoms(self) -> Optional[List[str]]: ...

    @property_value_uoms.setter
    def property_value_uoms(self, property_value_uoms: Optional[List[str]]) -> None: ...

    @property
    def property_values(self) -> List[str]: ...

    @property_values.setter
    def property_values(self, property_values: List[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ConditionsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_capsules(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def add_capsules_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_condition(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def condition_table(
        self,
        **kwargs: Any,
    ) -> TableResultOutputV1: ...

    def condition_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_condition(
        self,
        **kwargs: Any,
    ) -> ConditionOutputV1: ...

    def create_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_capsules(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_capsules_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_capsules(
        self,
        **kwargs: Any,
    ) -> CapsulesOutputV1: ...

    def get_capsules_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_condition(
        self,
        **kwargs: Any,
    ) -> ConditionOutputV1: ...

    def get_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_conditions(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_capsules(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def put_capsules_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_conditions(
        self,
        **kwargs: Any,
    ) -> ItemBatchOutputV1: ...

    def put_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_existing_condition(
        self,
        **kwargs: Any,
    ) -> ConditionOutputV1: ...

    def update_existing_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8
"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, Iterable, List, Optional, Sequence, Tuple, Union

from .configuration import ClientConfiguration


class ApiClient(object):
    configuration: ClientConfiguration
    host: str
    cookie: Optional[str]
    default_headers: Dict[str, Any]
    auth_token: Optional[str]
    identity_path: Optional[str]
    csrf_token: Optional[str]

    def __init__(
        self,
        host: Optional[str] = None,
        header_name: Optional[str] = None,
        header_value: Optional[str] = None,
        cookie: Optional[str] = None,
        configuration: Optional[ClientConfiguration] = None,
    ) -> None: ...

    def set_default_header(self, header_name: str, header_value: str) -> None: ...

    def call_api(
        self,
        resource_path: str,
        method: str,
        path_params: Optional[Dict[str, Any]] = None,
        query_params: Optional[List[Tuple[str, Any]]] = None,
        header_params: Optional[Dict[str, Any]] = None,
        body: Any = None,
        post_params: Any = None,
        files: Any = None,
        response_type: Optional[str] = None,
        auth_settings: Optional[Sequence[str]] = None,
        callback: Any = None,
        _return_http_data_only: Optional[bool] = None,
        _preload_content: bool = True,
        _request_timeout: Any = None,
        collection_formats: Optional[Dict[str, str]] = None,
    ) -> Any: ...

    def sanitize_for_serialization(self, obj: Any) -> Any: ...
    def deserialize(self, response_data: Any, response_type: Any) -> Any: ...

    def parameters_to_tuples(self, params: Any, collection_formats: Optional[Dict[str, str]] = None) -> List[Tuple[str, Any]]: ...

    def select_header_accept(self, accepts: Sequence[str]) -> Optional[str]: ...
    def select_header_content_type(self, content_types: Sequence[str]) -> str: ...

    def add_authorization_header(self, request_headers: Dict[str, Any]) -> None: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class RemoteAgentStatusInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _available_versions: List[str]
    _base_version: str
    _current_version: str
    _free_disk_space: int
    _pending_progress: Optional[float]
    _pending_status: Optional[str]
    _pending_version: Optional[str]
    _platform: str
    _platform_architecture: str
    _platform_version: str
    _status: Optional[str]
    _updates_enabled: bool


    def __init__(
        self,
        available_versions: Optional[List[str]] = None,
        base_version: Optional[str] = None,
        current_version: Optional[str] = None,
        free_disk_space: Optional[int] = None,
        pending_progress: Optional[float] = None,
        pending_status: Optional[str] = None,
        pending_version: Optional[str] = None,
        platform: Optional[str] = None,
        platform_architecture: Optional[str] = None,
        platform_version: Optional[str] = None,
        status: Optional[str] = None,
        updates_enabled: Optional[bool] = False,
    ) -> None: ...

    @property
    def available_versions(self) -> List[str]: ...

    @available_versions.setter
    def available_versions(self, available_versions: List[str]) -> None: ...

    @property
    def base_version(self) -> str: ...

    @base_version.setter
    def base_version(self, base_version: str) -> None: ...

    @property
    def current_version(self) -> str: ...

    @current_version.setter
    def current_version(self, current_version: str) -> None: ...

    @property
    def free_disk_space(self) -> int: ...

    @free_disk_space.setter
    def free_disk_space(self, free_disk_space: int) -> None: ...

    @property
    def pending_progress(self) -> Optional[float]: ...

    @pending_progress.setter
    def pending_progress(self, pending_progress: Optional[float]) -> None: ...

    @property
    def pending_status(self) -> Optional[str]: ...

    @pending_status.setter
    def pending_status(self, pending_status: Optional[str]) -> None: ...

    @property
    def pending_version(self) -> Optional[str]: ...

    @pending_version.setter
    def pending_version(self, pending_version: Optional[str]) -> None: ...

    @property
    def platform(self) -> str: ...

    @platform.setter
    def platform(self, platform: str) -> None: ...

    @property
    def platform_architecture(self) -> str: ...

    @platform_architecture.setter
    def platform_architecture(self, platform_architecture: str) -> None: ...

    @property
    def platform_version(self) -> str: ...

    @platform_version.setter
    def platform_version(self, platform_version: str) -> None: ...

    @property
    def status(self) -> Optional[str]: ...

    @status.setter
    def status(self, status: Optional[str]) -> None: ...

    @property
    def updates_enabled(self) -> bool: ...

    @updates_enabled.setter
    def updates_enabled(self, updates_enabled: bool) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class AuditApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_version_history(self, **kwargs):
        """
        Version a Locked item and create a new Version History.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_version_history(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VersionInputV1 body: Input object containing id of item to version and notes (optional) (required)
        :return: VersionHistoryOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VersionHistoryOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_version_history_with_http_info(**kwargs)
        else:
            (data) = self.create_version_history_with_http_info(**kwargs)
            return data

    def create_version_history_with_http_info(self, **kwargs):
        """
        Version a Locked item and create a new Version History.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_version_history_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VersionInputV1 body: Input object containing id of item to version and notes (optional) (required)
        :return: VersionHistoryOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VersionHistoryOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_version_history" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_version_history`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/audit/version', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'VersionHistoryOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_audit_entries(self, **kwargs):
        """
        Get a collection of Audit Trail entries
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_audit_entries(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str start_time: The start time for the query, formatted as an ISO 8601 timestamp (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)
        :param str end_time: The end time for the query, formatted as an ISO 8601 timestamp (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)
        :param list[str] user_id: User ID(s) to filter on
        :param list[str] item_id: Item ID(s) to filter on
        :param list[str] item_type: Item type(s) to filter on
        :param list[str] change_type: Change type(s) to filter on (Create, Update, Delete)
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :param bool sort_asc: When true sorts by oldest entries first, when false sorts by newest entries first
        :param bool hide_system_entries: When true, entries created by system managed users will be hidden from the results
        :param str search_field:
        :param str text_search:
        :param list[str] workbook_i_ds:
        :param bool include_unchanged_properties: When true, UPDATE and DELETE entries will include all item properties at that point in time, not just the properties that changed. Properties are accumulated from all prior entries in chronological order, providing the complete state of the properties at that time.
        :return: AuditOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuditOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_audit_entries_with_http_info(**kwargs)
        else:
            (data) = self.get_audit_entries_with_http_info(**kwargs)
            return data

    def get_audit_entries_with_http_info(self, **kwargs):
        """
        Get a collection of Audit Trail entries
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_audit_entries_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str start_time: The start time for the query, formatted as an ISO 8601 timestamp (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)
        :param str end_time: The end time for the query, formatted as an ISO 8601 timestamp (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)
        :param list[str] user_id: User ID(s) to filter on
        :param list[str] item_id: Item ID(s) to filter on
        :param list[str] item_type: Item type(s) to filter on
        :param list[str] change_type: Change type(s) to filter on (Create, Update, Delete)
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :param bool sort_asc: When true sorts by oldest entries first, when false sorts by newest entries first
        :param bool hide_system_entries: When true, entries created by system managed users will be hidden from the results
        :param str search_field:
        :param str text_search:
        :param list[str] workbook_i_ds:
        :param bool include_unchanged_properties: When true, UPDATE and DELETE entries will include all item properties at that point in time, not just the properties that changed. Properties are accumulated from all prior entries in chronological order, providing the complete state of the properties at that time.
        :return: AuditOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuditOutputListV1
        """

        all_params = ['start_time', 'end_time', 'user_id', 'item_id', 'item_type', 'change_type', 'offset', 'limit', 'sort_asc', 'hide_system_entries', 'search_field', 'text_search', 'workbook_i_ds', 'include_unchanged_properties']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_audit_entries" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))
        if 'user_id' in params:
            query_params.append(('userID', params['user_id']))
            collection_formats['userID'] = 'multi'
        if 'item_id' in params:
            query_params.append(('itemID', params['item_id']))
            collection_formats['itemID'] = 'multi'
        if 'item_type' in params:
            query_params.append(('itemType', params['item_type']))
            collection_formats['itemType'] = 'multi'
        if 'change_type' in params:
            query_params.append(('changeType', params['change_type']))
            collection_formats['changeType'] = 'multi'
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'sort_asc' in params:
            query_params.append(('sortAsc', params['sort_asc']))
        if 'hide_system_entries' in params:
            query_params.append(('hideSystemEntries', params['hide_system_entries']))
        if 'search_field' in params:
            query_params.append(('searchField', params['search_field']))
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))
        if 'workbook_i_ds' in params:
            query_params.append(('workbookIDs', params['workbook_i_ds']))
            collection_formats['workbookIDs'] = 'multi'
        if 'include_unchanged_properties' in params:
            query_params.append(('includeUnchangedProperties', params['include_unchanged_properties']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/audit', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'AuditOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_version_histories(self, **kwargs):
        """
        Get all the Version Histories this user has access to, or get all the Version Histories pertaining to an item that was created by cloning a versioned item.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_version_histories(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param bool is_archived:
        :param str duplicate_item_id:
        :param list[str] versioned_item_type: Optional filter on the type of items versioned by the returned Version Histories. Repeat this query parameter to include multiple types.
        :return: VersionHistoryOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VersionHistoryOutputListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_version_histories_with_http_info(**kwargs)
        else:
            (data) = self.get_version_histories_with_http_info(**kwargs)
            return data

    def get_version_histories_with_http_info(self, **kwargs):
        """
        Get all the Version Histories this user has access to, or get all the Version Histories pertaining to an item that was created by cloning a versioned item.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_version_histories_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param bool is_archived:
        :param str duplicate_item_id:
        :param list[str] versioned_item_type: Optional filter on the type of items versioned by the returned Version Histories. Repeat this query parameter to include multiple types.
        :return: VersionHistoryOutputListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VersionHistoryOutputListV1
        """

        all_params = ['is_archived', 'duplicate_item_id', 'versioned_item_type']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_version_histories" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'is_archived' in params:
            query_params.append(('isArchived', params['is_archived']))
        if 'duplicate_item_id' in params:
            query_params.append(('duplicateItemId', params['duplicate_item_id']))
        if 'versioned_item_type' in params:
            query_params.append(('versionedItemType', params['versioned_item_type']))
            collection_formats['versionedItemType'] = 'multi'

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/audit/version-histories', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'VersionHistoryOutputListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_version_history(self, **kwargs):
        """
        Get a specific Version History that this user has access to
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_version_history(version_history_id=version_history_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str version_history_id: (required)
        :return: VersionHistoryOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VersionHistoryOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_version_history_with_http_info(**kwargs)
        else:
            (data) = self.get_version_history_with_http_info(**kwargs)
            return data

    def get_version_history_with_http_info(self, **kwargs):
        """
        Get a specific Version History that this user has access to
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_version_history_with_http_info(version_history_id=version_history_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str version_history_id: (required)
        :return: VersionHistoryOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VersionHistoryOutputV1
        """

        all_params = ['version_history_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_version_history" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_history_id' is set
        if ('version_history_id' not in params) or (params['version_history_id'] is None):
            raise ValueError("Missing the required parameter `version_history_id` when calling `get_version_history`")


        collection_formats = {}

        path_params = {}
        if 'version_history_id' in params:
            path_params['versionHistoryId'] = params['version_history_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/audit/version-history/{versionHistoryId}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'VersionHistoryOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_version_history(self, **kwargs):
        """
        Version a Locked item and add it to an existing Version History.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_version_history(body=body_value, version_history_id=version_history_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VersionInputV1 body: Input object containing id of item to version and notes (required)
        :param str version_history_id: ID of the Version History to add this Version to. (required)
        :return: VersionHistoryOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VersionHistoryOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_version_history_with_http_info(**kwargs)
        else:
            (data) = self.update_version_history_with_http_info(**kwargs)
            return data

    def update_version_history_with_http_info(self, **kwargs):
        """
        Version a Locked item and add it to an existing Version History.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_version_history_with_http_info(body=body_value, version_history_id=version_history_id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VersionInputV1 body: Input object containing id of item to version and notes (required)
        :param str version_history_id: ID of the Version History to add this Version to. (required)
        :return: VersionHistoryOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VersionHistoryOutputV1
        """

        all_params = ['body', 'version_history_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_version_history" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_version_history`")
        # verify the required parameter 'version_history_id' is set
        if ('version_history_id' not in params) or (params['version_history_id'] is None):
            raise ValueError("Missing the required parameter `version_history_id` when calling `update_version_history`")


        collection_formats = {}

        path_params = {}
        if 'version_history_id' in params:
            path_params['versionHistoryId'] = params['version_history_id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/audit/version/{versionHistoryId}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'VersionHistoryOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ContextNumericOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _archived: bool
    _archived_at: Optional[str]
    _archiver_id: Optional[str]
    _context: str
    _context_id: str
    _created_at: str
    _created_by: Optional[ContextUser]
    _creator_id: str
    _datum_id: Optional[str]
    _end_time: Optional[str]
    _item: Optional[ContextItem]
    _item_id: str
    _numeric_description_id: Optional[str]
    _numeric_description_name: Optional[str]
    _source: Optional[ContextSourceOutputV1]
    _start_time: Optional[str]
    _updated_at: Optional[str]
    _value: Optional[float]


    def __init__(
        self,
        archived: Optional[bool] = None,
        archived_at: Optional[str] = None,
        archiver_id: Optional[str] = None,
        context: Optional[str] = None,
        context_id: Optional[str] = None,
        created_at: Optional[str] = None,
        created_by: Optional[ContextUser] = None,
        creator_id: Optional[str] = None,
        datum_id: Optional[str] = None,
        end_time: Optional[str] = None,
        item: Optional[ContextItem] = None,
        item_id: Optional[str] = None,
        numeric_description_id: Optional[str] = None,
        numeric_description_name: Optional[str] = None,
        source: Optional[ContextSourceOutputV1] = None,
        start_time: Optional[str] = None,
        updated_at: Optional[str] = None,
        value: Optional[float] = None,
    ) -> None: ...

    @property
    def archived(self) -> bool: ...

    @archived.setter
    def archived(self, archived: bool) -> None: ...

    @property
    def archived_at(self) -> Optional[str]: ...

    @archived_at.setter
    def archived_at(self, archived_at: Optional[str]) -> None: ...

    @property
    def archiver_id(self) -> Optional[str]: ...

    @archiver_id.setter
    def archiver_id(self, archiver_id: Optional[str]) -> None: ...

    @property
    def context(self) -> str: ...

    @context.setter
    def context(self, context: str) -> None: ...

    @property
    def context_id(self) -> str: ...

    @context_id.setter
    def context_id(self, context_id: str) -> None: ...

    @property
    def created_at(self) -> str: ...

    @created_at.setter
    def created_at(self, created_at: str) -> None: ...

    @property
    def created_by(self) -> Optional[ContextUser]: ...

    @created_by.setter
    def created_by(self, created_by: Optional[ContextUser]) -> None: ...

    @property
    def creator_id(self) -> str: ...

    @creator_id.setter
    def creator_id(self, creator_id: str) -> None: ...

    @property
    def datum_id(self) -> Optional[str]: ...

    @datum_id.setter
    def datum_id(self, datum_id: Optional[str]) -> None: ...

    @property
    def end_time(self) -> Optional[str]: ...

    @end_time.setter
    def end_time(self, end_time: Optional[str]) -> None: ...

    @property
    def item(self) -> Optional[ContextItem]: ...

    @item.setter
    def item(self, item: Optional[ContextItem]) -> None: ...

    @property
    def item_id(self) -> str: ...

    @item_id.setter
    def item_id(self, item_id: str) -> None: ...

    @property
    def numeric_description_id(self) -> Optional[str]: ...

    @numeric_description_id.setter
    def numeric_description_id(self, numeric_description_id: Optional[str]) -> None: ...

    @property
    def numeric_description_name(self) -> Optional[str]: ...

    @numeric_description_name.setter
    def numeric_description_name(self, numeric_description_name: Optional[str]) -> None: ...

    @property
    def source(self) -> Optional[ContextSourceOutputV1]: ...

    @source.setter
    def source(self, source: Optional[ContextSourceOutputV1]) -> None: ...

    @property
    def start_time(self) -> Optional[str]: ...

    @start_time.setter
    def start_time(self, start_time: Optional[str]) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    @property
    def value(self) -> Optional[float]: ...

    @value.setter
    def value(self, value: Optional[float]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SyncProgress(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _asset_count: Optional[int]
    _asset_progress: Optional[int]
    _condition_count: Optional[int]
    _condition_progress: Optional[int]
    _relationship_count: Optional[int]
    _relationship_progress: Optional[int]
    _scalar_count: Optional[int]
    _scalar_progress: Optional[int]
    _signal_count: Optional[int]
    _signal_progress: Optional[int]
    _user_group_count: Optional[int]
    _user_group_progress: Optional[int]


    def __init__(
        self,
        asset_count: Optional[int] = None,
        asset_progress: Optional[int] = None,
        condition_count: Optional[int] = None,
        condition_progress: Optional[int] = None,
        relationship_count: Optional[int] = None,
        relationship_progress: Optional[int] = None,
        scalar_count: Optional[int] = None,
        scalar_progress: Optional[int] = None,
        signal_count: Optional[int] = None,
        signal_progress: Optional[int] = None,
        user_group_count: Optional[int] = None,
        user_group_progress: Optional[int] = None,
    ) -> None: ...

    @property
    def asset_count(self) -> Optional[int]: ...

    @asset_count.setter
    def asset_count(self, asset_count: Optional[int]) -> None: ...

    @property
    def asset_progress(self) -> Optional[int]: ...

    @asset_progress.setter
    def asset_progress(self, asset_progress: Optional[int]) -> None: ...

    @property
    def condition_count(self) -> Optional[int]: ...

    @condition_count.setter
    def condition_count(self, condition_count: Optional[int]) -> None: ...

    @property
    def condition_progress(self) -> Optional[int]: ...

    @condition_progress.setter
    def condition_progress(self, condition_progress: Optional[int]) -> None: ...

    @property
    def relationship_count(self) -> Optional[int]: ...

    @relationship_count.setter
    def relationship_count(self, relationship_count: Optional[int]) -> None: ...

    @property
    def relationship_progress(self) -> Optional[int]: ...

    @relationship_progress.setter
    def relationship_progress(self, relationship_progress: Optional[int]) -> None: ...

    @property
    def scalar_count(self) -> Optional[int]: ...

    @scalar_count.setter
    def scalar_count(self, scalar_count: Optional[int]) -> None: ...

    @property
    def scalar_progress(self) -> Optional[int]: ...

    @scalar_progress.setter
    def scalar_progress(self, scalar_progress: Optional[int]) -> None: ...

    @property
    def signal_count(self) -> Optional[int]: ...

    @signal_count.setter
    def signal_count(self, signal_count: Optional[int]) -> None: ...

    @property
    def signal_progress(self) -> Optional[int]: ...

    @signal_progress.setter
    def signal_progress(self, signal_progress: Optional[int]) -> None: ...

    @property
    def user_group_count(self) -> Optional[int]: ...

    @user_group_count.setter
    def user_group_count(self, user_group_count: Optional[int]) -> None: ...

    @property
    def user_group_progress(self) -> Optional[int]: ...

    @user_group_progress.setter
    def user_group_progress(self, user_group_progress: Optional[int]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class MonitoredSignalLastRunStateOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cursor_key: Optional[int]
    _error_count: Optional[int]
    _last_certain_sample: Optional[SampleOutputV1]
    _last_error: Optional[str]
    _last_error_time_created: Optional[int]
    _signal_guid: str
    _uncertain_samples: Optional[List[SampleOutputV1]]


    def __init__(
        self,
        cursor_key: Optional[int] = None,
        error_count: Optional[int] = None,
        last_certain_sample: Optional[SampleOutputV1] = None,
        last_error: Optional[str] = None,
        last_error_time_created: Optional[int] = None,
        signal_guid: Optional[str] = None,
        uncertain_samples: Optional[List[SampleOutputV1]] = None,
    ) -> None: ...

    @property
    def cursor_key(self) -> Optional[int]: ...

    @cursor_key.setter
    def cursor_key(self, cursor_key: Optional[int]) -> None: ...

    @property
    def error_count(self) -> Optional[int]: ...

    @error_count.setter
    def error_count(self, error_count: Optional[int]) -> None: ...

    @property
    def last_certain_sample(self) -> Optional[SampleOutputV1]: ...

    @last_certain_sample.setter
    def last_certain_sample(self, last_certain_sample: Optional[SampleOutputV1]) -> None: ...

    @property
    def last_error(self) -> Optional[str]: ...

    @last_error.setter
    def last_error(self, last_error: Optional[str]) -> None: ...

    @property
    def last_error_time_created(self) -> Optional[int]: ...

    @last_error_time_created.setter
    def last_error_time_created(self, last_error_time_created: Optional[int]) -> None: ...

    @property
    def signal_guid(self) -> str: ...

    @signal_guid.setter
    def signal_guid(self, signal_guid: str) -> None: ...

    @property
    def uncertain_samples(self) -> Optional[List[SampleOutputV1]]: ...

    @uncertain_samples.setter
    def uncertain_samples(self, uncertain_samples: Optional[List[SampleOutputV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
